@@ -118,6 +118,27 @@ func TestConfigRuntimeArgs(t *testing.T) {
 				assert.NotEqual(t, []string{}, conf.Build.ExcludeDir)
 			},
 		},
+		{
+			name: "check full_bin",
+			args: []string{"--build.full_bin", "APP_ENV=dev APP_USER=air ./tmp/main"},
+			check: func(t *testing.T, conf *Config) {
+				assert.Equal(t, "APP_ENV=dev APP_USER=air ./tmp/main", conf.Build.Bin)
+			},
+		},
+
+		{
+			name: "check exclude_regex patterns compiled",
+			args: []string{"--build.exclude_regex", "test_pattern\\.go"},
+			check: func(t *testing.T, conf *Config) {
+				assert.Equal(t, []string{"test_pattern\\.go"}, conf.Build.ExcludeRegex)
+				patterns, err := conf.Build.RegexCompiled()
+				require.NoError(t, err)
+				require.NotNil(t, patterns)
+				require.Len(t, patterns, 1)
+				assert.True(t, patterns[0].MatchString("test_pattern.go"), "regex should match test_pattern.go")
+				assert.False(t, patterns[0].MatchString("other_file.go"), "regex shouldn't match other_file.go")
+			},
+		},
 	}
 	for _, tc := range testCases {
 		t.Run(tc.name, func(t *testing.T) {
@@ -126,12 +147,11 @@ func TestConfigRuntimeArgs(t *testing.T) {
 			flag := flag.NewFlagSet(t.Name(), flag.ExitOnError)
 			cmdArgs := ParseConfigFlag(flag)
 			_ = flag.Parse(tc.args)
-			cfg, err := InitConfig("")
+			cfg, err := InitConfig("", cmdArgs)
 			if err != nil {
 				log.Fatal(err)
 				return
 			}
-			cfg.WithArgs(cmdArgs)
 			tc.check(t, cfg)
 		})
 	}
